# CascaderSelect

-   category: Components
-   family: DataEntry
-   chinese: 级联选择
-   type: 基本

---

## Guide

### When To Use

CascaderSelect consists of Select and Cascader. Cascader are hidden in a pop up layer by default and are mostly used in form scenes.

## API

### CascaderSelect

| Param           | Description                                                                                                                  | Type       | Default Value          |
| -------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ----------------------- | ---------------------------- |
| size                 | size of selector<br><br>**options**:<br>'small', 'medium', 'large'                                                                                                                                                                                                                                                                                                                                                                                                                                                                        | Enum                    | 'medium'                     |
| placeholder          | placeholder of selector                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     | String                  | -                            |
| disabled             | whether is disabled                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | Boolean                 | false                        |
| hasArrow             | whether has arrow icon                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | Boolean                 | true                         |
| hasBorder            | whether selector has border                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      | Boolean                 | true                         |
| hasClear             | whether has clear button                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | Boolean                 | false                        |
| label                | custom inline label                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | ReactNode               | -                            |
| readOnly             | whether selector is read only, it can be expanded but cannot be selected under read only mode                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | Boolean                 | -                            |
| dataSource           | data source, structure can refer to the following document                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | Array&lt;Object>        | \[]                          |
| defaultValue         | (under uncontrol) default value                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | String/Array&lt;String> | null                         |
| value                | (under control) current value                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | String/Array&lt;String> | -                            |
| onChange             | callback triggered when value changes<br><br>**signatures**:<br>Function(value: String/Array, data: Object/Array, extra: Object) => void<br>**params**:<br>_value_: {String/Array} selected value, a single value is returned when single select, and an array is returned when multiple select<br>_data_: {Object/Array} selected data, including value, label, returns a single value when single select, returns an array when multiple select, parent and child nodes are selected at the same time, only the parent node is returned<br>_extra_: {Object} extra param<br>_extra.selectedPath_: {Array} path of the selected data when single selecte<br>_extra.checked_: {Boolean} whether is checked when multiple select<br>_extra.currentData_: {Object} current operation data when multiple select<br>_extra.checkedData_: {Array} all checked data when multiple select<br>_extra.indeterminateData_: {Array} indeterminate data when multile selec | Function                | -                            |
| defaultExpandedValue | (under uncontrol) default expanded value, if not set, the component will be automatically set according to defaultValue/value                                                                                                                                                                                                                                                                                                                                                                                                                                                                              | Array&lt;String>        | -                            |
| expandTriggerType    | expand trigger type<br><br>**options**:<br>'click', 'hover'                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | Enum                    | 'click'                      |
| multiple             | whether is multiple select                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | Boolean                 | false                        |
| changeOnSelect       | change immediately if selected, this property is only worked in single selection mode                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | Boolean                 | false                        |
| canOnlyCheckLeaf     | whether checkbox of leaf item can only be checked, this property is only worked in multiple selection mode                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            | Boolean                 | false                        |
| checkStrictly        | whether selection of parent and child nodes are related                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | Boolean                 | false                        |
| listStyle            | style of list                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | Object                  | -                            |
| listClassName        | class name of list                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     | String                  | -                            |
| displayRender        | custom rendering function to display results<br><br>**signatures**:<br>Function(label: Array) => ReactNode<br>**params**:<br>_label_: {Array} label array of the selected path<br>**returns**:<br>{ReactNode} display content<br>                                                                                                                                                                                                                                                                                                                                                                | Function                | single select: labelPath => labelPath.join(' / '); multiple select: labelPath => labelPath[labelPath.length - 1] |
| showSearch           | whether to show the search box                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | Boolean                 | false                        |
| filter               | custom search function<br><br>**signatures**:<br>Function(searchValue: String, path: Array) => Boolean<br>**params**:<br>_searchValue_: {String} search keyword<br>_path_: {Array} item path<br>**returns**:<br>{Boolean} whether is matched<br>                                                                                                                                                                                                                                                                                                                                     | Function                | fuzzy matching of label based on all nodes of the path             |
| resultRender         | custom render function of search result<br><br>**signatures**:<br>Function(searchValue: String, path: Array) => ReactNode<br>**params**:<br>_searchValue_: {String} search keyword<br>_path_: {Array} matched item path<br>**returns**:<br>{ReactNode} result content<br>                                                                                                                                                                                                                                                                                                                        | Function                | rendering by pattern of a / b / c       |
| resultAutoWidth      | whether the search result list is equal to the selector                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | Boolean                 | true                         |
| notFoundContent      | content without data                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | ReactNode               | 'Not Found'                  |
| loadData             | asynchronous data loading function<br><br>**signatures**:<br>Function(data: Object) => void<br>**params**:<br>_data_: {Object} data of the clicked item                                                                                                                                                                                                                                                                                                                                                                                                                       | Function                | -                            |
| header               | custom dropdown header                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | ReactNode               | -                            |
| footer               | custom dropdown footer                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | ReactNode               | -                            |
| defaultVisible       | whether dropdown is default visible                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  | Boolean                 | false                        |
| visible              | whether dropdown is current visible                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 | Boolean                 | -                            |
| onVisibleChange      | callback triggered when open or close dropdown <br><br>**signatures**:<br>Function(visible: Boolean, type: String) => void<br>**params**:<br>_visible_: {Boolean} whether is visible<br>_type_: {String} trigger type                                                                                                                                                                                                                                                                                                                                                              | Function                | () => {}                     |
| popupStyle           | style of dropdown                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | Object                  | -                            |
| popupClassName       | className of dropdown                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | String                  | -                            |
| popupContainer       | container of dropdown                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 | String/Function         | -                            |
| popupProps           | properties of Popup                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            | Object                  | {}                           |
| followTrigger        | follow Trigger or not                                                                                                                                                      | Boolean         | -                                         |

<!-- api-extra-start -->

### Data structure of dataSource

```js
const dataSource = [{
    value: '2974',
    label: '西安',
    children: [
        { value: '2975', label: '西安市', disabled: true },
        { value: '2976', label: '高陵县', checkboxDisabled: true },
        { value: '2977', label: '蓝田县' },
        { value: '2978', label: '户县' },
        { value: '2979', label: '周至县' },
        { value: '4208', label: '灞桥区' },
        { value: '4209', label: '长安区' },
        { value: '4210', label: '莲湖区' },
        { value: '4211', label: '临潼区' },
        { value: '4212', label: '未央区' },
        { value: '4213', label: '新城区' },
        { value: '4214', label: '阎良区' },
        { value: '4215', label: '雁塔区' },
        { value: '4388', label: '碑林区' },
        { value: '610127', label: '其它区' }
    ]
}];
```

The custom attribute of item in the array is also transparently passed to the data parameter of the onChange function.

<!-- api-extra-end -->


## ARIA and KeyBoard

| 按键          | 说明                              |
| :---------- | :------------------------------ |
| Up Arrow    | Get the previous item focus of the current item of same level   |
| Down Arrow  | Get the next item focus of the current item of same level  |
| Left Arrow  | Enter the child element of the current item and get the first child element as the focus |
| Right Arrow | Returns the parent of the current item and gets the focus |
| Enter       | Open the directory or select current item              |
| Esc         | Close the directory     |
| SPACE       | Select current item              |







