{"title":"ErrorBoundary 捕获错误","meta":{"title":"ErrorBoundary 捕获错误","description":"\n<p>使用 <code>&lt;ErrorBoundary&gt;</code> 可以避免由于局部区域的错误，所引起的页面白屏。</p>\n","order":"5"},"codes":{"jsx":"import { ConfigProvider, Button } from '@alifd/next';\n\nconst { ErrorBoundary, config } = ConfigProvider;\n\nclass Demo extends React.Component {\n    render() {\n        if (this.props.throwError) {\n            throw Error('There is something going wrong!');\n        } else {\n            return (\n                <span>normal</span>\n            );\n        }\n    }\n}\n\nconst NewDemo = config(Demo);\n\nconst fallbackUI = (props) => {\n    const { error, errorInfo } = props;\n    return <span style={{color: 'red'}}>{error.toString()}</span>;\n};\n\nclass App extends React.Component {\n    state = {\n        throwError: false\n    };\n\n    onClick = () => {\n        this.setState({\n            throwError: true\n        });\n    };\n\n    render() {\n        return (<div>\n            Click to throw an error <Button type=\"primary\" onClick={this.onClick}>trigger error</Button>\n            <br/>\n            <br/>\n            Default fallback UI:\n            <hr />\n            <ConfigProvider errorBoundary>\n                <NewDemo throwError={this.state.throwError}/>\n            </ConfigProvider>\n            <br/>\n            <br/>\n            Customize fallback UI of configed Component(Basic Components / Biz Components):\n            <hr />\n            <ConfigProvider errorBoundary={{\n                fallbackUI: props => {\n                    const { error, errorInfo } = props;\n                    return <span style={{color: 'red'}}>Error: {error.toString()}</span>;\n                },\n                afterCatch: () => {\n                    console.log('catching');\n                }\n            }}>\n                <NewDemo throwError={this.state.throwError}/>\n            </ConfigProvider>\n        </div>);\n    }\n}\n\nReactDOM.render(<App />, mountNode);\n"},"body":"\n\n````jsx\nimport { ConfigProvider, Button } from '@alifd/next';\n\nconst { ErrorBoundary, config } = ConfigProvider;\n\nclass Demo extends React.Component {\n    render() {\n        if (this.props.throwError) {\n            throw Error('There is something going wrong!');\n        } else {\n            return (\n                <span>normal</span>\n            );\n        }\n    }\n}\n\nconst NewDemo = config(Demo);\n\nconst fallbackUI = (props) => {\n    const { error, errorInfo } = props;\n    return <span style={{color: 'red'}}>{error.toString()}</span>;\n};\n\nclass App extends React.Component {\n    state = {\n        throwError: false\n    };\n\n    onClick = () => {\n        this.setState({\n            throwError: true\n        });\n    };\n\n    render() {\n        return (<div>\n            Click to throw an error <Button type=\"primary\" onClick={this.onClick}>trigger error</Button>\n            <br/>\n            <br/>\n            Default fallback UI:\n            <hr />\n            <ConfigProvider errorBoundary>\n                <NewDemo throwError={this.state.throwError}/>\n            </ConfigProvider>\n            <br/>\n            <br/>\n            Customize fallback UI of configed Component(Basic Components / Biz Components):\n            <hr />\n            <ConfigProvider errorBoundary={{\n                fallbackUI: props => {\n                    const { error, errorInfo } = props;\n                    return <span style={{color: 'red'}}>Error: {error.toString()}</span>;\n                },\n                afterCatch: () => {\n                    console.log('catching');\n                }\n            }}>\n                <NewDemo throwError={this.state.throwError}/>\n            </ConfigProvider>\n        </div>);\n    }\n}\n\nReactDOM.render(<App />, mountNode);\n````","html":"<script>(function(){'use strict';\n\nvar _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();\n\nvar _next = require('@alifd/next');\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return call && (typeof call === \"object\" || typeof call === \"function\") ? call : self; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function, not \" + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }\n\nvar ErrorBoundary = _next.ConfigProvider.ErrorBoundary,\n    config = _next.ConfigProvider.config;\n\nvar Demo = function (_React$Component) {\n    _inherits(Demo, _React$Component);\n\n    function Demo() {\n        _classCallCheck(this, Demo);\n\n        return _possibleConstructorReturn(this, (Demo.__proto__ || Object.getPrototypeOf(Demo)).apply(this, arguments));\n    }\n\n    _createClass(Demo, [{\n        key: 'render',\n        value: function render() {\n            if (this.props.throwError) {\n                throw Error('There is something going wrong!');\n            } else {\n                return React.createElement(\n                    'span',\n                    null,\n                    'normal'\n                );\n            }\n        }\n    }]);\n\n    return Demo;\n}(React.Component);\n\nvar NewDemo = config(Demo);\n\nvar fallbackUI = function fallbackUI(props) {\n    var error = props.error,\n        errorInfo = props.errorInfo;\n\n    return React.createElement(\n        'span',\n        { style: { color: 'red' } },\n        error.toString()\n    );\n};\n\nvar App = function (_React$Component2) {\n    _inherits(App, _React$Component2);\n\n    function App() {\n        var _ref;\n\n        var _temp, _this2, _ret;\n\n        _classCallCheck(this, App);\n\n        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {\n            args[_key] = arguments[_key];\n        }\n\n        return _ret = (_temp = (_this2 = _possibleConstructorReturn(this, (_ref = App.__proto__ || Object.getPrototypeOf(App)).call.apply(_ref, [this].concat(args))), _this2), _this2.state = {\n            throwError: false\n        }, _this2.onClick = function () {\n            _this2.setState({\n                throwError: true\n            });\n        }, _temp), _possibleConstructorReturn(_this2, _ret);\n    }\n\n    _createClass(App, [{\n        key: 'render',\n        value: function render() {\n            return React.createElement(\n                'div',\n                null,\n                'Click to throw an error ',\n                React.createElement(\n                    _next.Button,\n                    { type: 'primary', onClick: this.onClick },\n                    'trigger error'\n                ),\n                React.createElement('br', null),\n                React.createElement('br', null),\n                'Default fallback UI:',\n                React.createElement('hr', null),\n                React.createElement(\n                    _next.ConfigProvider,\n                    { errorBoundary: true },\n                    React.createElement(NewDemo, { throwError: this.state.throwError })\n                ),\n                React.createElement('br', null),\n                React.createElement('br', null),\n                'Customize fallback UI of configed Component(Basic Components / Biz Components):',\n                React.createElement('hr', null),\n                React.createElement(\n                    _next.ConfigProvider,\n                    { errorBoundary: {\n                            fallbackUI: function fallbackUI(props) {\n                                var error = props.error,\n                                    errorInfo = props.errorInfo;\n\n                                return React.createElement(\n                                    'span',\n                                    { style: { color: 'red' } },\n                                    'Error: ',\n                                    error.toString()\n                                );\n                            },\n                            afterCatch: function afterCatch() {\n                                console.log('catching');\n                            }\n                        } },\n                    React.createElement(NewDemo, { throwError: this.state.throwError })\n                )\n            );\n        }\n    }]);\n\n    return App;\n}(React.Component);\n\nReactDOM.render(React.createElement(App, null), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> ConfigProvider<span class=\"token punctuation\">,</span> Button <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> ErrorBoundary<span class=\"token punctuation\">,</span> config <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> ConfigProvider<span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">Demo</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span>throwError<span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n            <span class=\"token keyword\">throw</span> <span class=\"token function\">Error</span><span class=\"token punctuation\">(</span><span class=\"token string\">'There is something going wrong!'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        <span class=\"token punctuation\">}</span> <span class=\"token keyword\">else</span> <span class=\"token punctuation\">{</span>\n            <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span>\n                <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>span</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">normal</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>span</span><span class=\"token punctuation\">></span></span>\n            <span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        <span class=\"token punctuation\">}</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token keyword\">const</span> NewDemo <span class=\"token operator\">=</span> <span class=\"token function\">config</span><span class=\"token punctuation\">(</span>Demo<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> <span class=\"token function-variable function\">fallbackUI</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token parameter\">props</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> error<span class=\"token punctuation\">,</span> errorInfo <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> props<span class=\"token punctuation\">;</span>\n    <span class=\"token keyword\">return</span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>span</span> <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span>color<span class=\"token punctuation\">:</span> <span class=\"token string\">'red'</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>error<span class=\"token punctuation\">.</span><span class=\"token function\">toString</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>span</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">App</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    state <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n        throwError<span class=\"token punctuation\">:</span> <span class=\"token boolean\">false</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token function-variable function\">onClick</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            throwError<span class=\"token punctuation\">:</span> <span class=\"token boolean\">true</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            Click to throw an error </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">type</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>primary<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>onClick<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">trigger error</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>br</span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>br</span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n            Default fallback UI:\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>hr</span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">ConfigProvider</span></span> <span class=\"token attr-name\">errorBoundary</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">NewDemo</span></span> <span class=\"token attr-name\">throwError</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>throwError<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">ConfigProvider</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>br</span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>br</span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n            Customize fallback UI of configed Component(Basic Components / Biz Components):\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>hr</span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n            &lt;ConfigProvider errorBoundary=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span>\n                <span class=\"token function-variable function\">fallbackUI</span><span class=\"token punctuation\">:</span> <span class=\"token parameter\">props</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n                    <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> error<span class=\"token punctuation\">,</span> errorInfo <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> props<span class=\"token punctuation\">;</span>\n                    <span class=\"token keyword\">return</span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>span</span> <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span>color<span class=\"token punctuation\">:</span> <span class=\"token string\">'red'</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Error: </span><span class=\"token punctuation\">{</span>error<span class=\"token punctuation\">.</span><span class=\"token function\">toString</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>span</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">;</span>\n                <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n                <span class=\"token function-variable function\">afterCatch</span><span class=\"token punctuation\">:</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n                    console<span class=\"token punctuation\">.</span><span class=\"token function\">log</span><span class=\"token punctuation\">(</span><span class=\"token string\">'catching'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n                <span class=\"token punctuation\">}</span>\n            <span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span><span class=\"token plain-text\">>\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">NewDemo</span></span> <span class=\"token attr-name\">throwError</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>throwError<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">ConfigProvider</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">App</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div>"}