{"meta":"<h2 id=\"guide\">Guide<a href=\"#guide\" class=\"anchor\">#</a></h2><h3 id=\"basic-usage\">Basic Usage<a href=\"#basic-usage\" class=\"anchor\">#</a></h3><p>This grid system provides response rules for almost all mainstream resolution scenes such as 320, 480, 720, 990, 1200, and 1500. The responsive grids are implemented using a 24-column and a 5-point to meet 2, 3, 4, 5, and 6 ratio layouts. The fixed grid uses a 20px width as the unit, it is recommended to use 9, 10, 12, 14, 16, 18, 24, but all from 1 to 30 are also available. You can also customize the fixed grid columns according to your requirements. The breakpoint are: xss(320px), xs(480px), s(720px), m(990px), l(1200px), xl(1500px). Based on the Flex implementation, IE9 is compatible with <code>display:table;</code>, but IE9 only supports basic responsive layouts (see API and DEMO for details).</p>\n<h3 id=\"accessibility\">Accessibility<a href=\"#accessibility\" class=\"anchor\">#</a></h3><p>Though we have build-in support of a11y by adding <code>&lt;Row&gt;</code> and <code>&lt;Col&gt;</code> with <code>role=&quot;row&quot;</code> and <code>role=&quot;gridcell&quot;</code> respectively, in order to achieve more a11y compliance, developers are also expected to add <code>role=&quot;grid&quot;</code> in the outer wrapper element, as this:</p>\n<pre>&lt;div role=&quot;grid&quot;&gt;\n    &lt;Row&gt;&lt;Col span={6}&gt;1&lt;/Col&gt;&lt;Col span={6}&gt;2&lt;/Col&gt;&lt;Col span={6}&gt;3&lt;/Col&gt;&lt;Col span={6}&gt;4&lt;/Col&gt;&lt;/Row&gt;\n    &lt;Row&gt;&lt;Col span={6} offset={6}&gt;1&lt;/Col&gt;&lt;Col span={6} offset={6}&gt;2&lt;/Col&gt;&lt;/Row&gt;\n&lt;/div&gt;</pre><h2 id=\"api\">API<a href=\"#api\" class=\"anchor\">#</a></h2>","api":"<h3 id=\"grid-row\">Grid.Row<a href=\"#grid-row\" class=\"anchor\">#</a></h3><table>\n<thead>\n<tr>\n<th>Param</th>\n<th>Descripiton</th>\n<th>Type</th>\n<th>Default Value</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td>children</td>\n<td>content of the row</td>\n<td>ReactNode</td>\n<td>-</td>\n</tr>\n<tr>\n<td>gutter</td>\n<td>spacing of the columns</td>\n<td>String/Number</td>\n<td>0</td>\n</tr>\n<tr>\n<td>wrap</td>\n<td>whether the row is wrap while width overflow</td>\n<td>Boolean</td>\n<td>false</td>\n</tr>\n<tr>\n<td>fixed</td>\n<td>whether the width of the row stays the same under a certain breakpoint (the default row width varies depending on the viewport)</td>\n<td>Boolean</td>\n<td>false</td>\n</tr>\n<tr>\n<td>fixedWidth</td>\n<td>the width of the fixed row is the width of a certain breakpoint and it is not affected by the viewport.<br><br><strong>option</strong>:<br>&apos;xxs&apos;(320px)<br>&apos;xs&apos;(480px)<br>&apos;s&apos;(720px)<br>&apos;m&apos;(990px)<br>&apos;l&apos;(1200px)<br>&apos;xl&apos;(1500px)</td>\n<td>Enum</td>\n<td>-</td>\n</tr>\n<tr>\n<td>align</td>\n<td>(IE9 is not supported) vertical alignment of columns<br><br><strong>option</strong>:<br>&apos;top&apos;<br>&apos;center&apos;<br>&apos;bottom&apos;<br>&apos;baseline&apos;<br>&apos;stretch&apos;</td>\n<td>Enum</td>\n<td>&apos;stretch&apos;</td>\n</tr>\n<tr>\n<td>justify</td>\n<td>(IE9 is not supported) horizontal alignment of columns<br><br><strong>option</strong>:<br>&apos;start&apos;<br>&apos;center&apos;<br>&apos;end&apos;<br>&apos;space-between&apos;<br>&apos;space-around&apos;</td>\n<td>Enum</td>\n<td>&apos;start&apos;</td>\n</tr>\n<tr>\n<td>hidden</td>\n<td>whether display or hide the row under different breakpoints.<br><br><strong>option</strong>:<br>true(always hide)<br>false(always display)<br>&apos;xs&apos;(hide under xs breakpoint&#xFF09;<br>[&apos;xxs&apos;, &apos;xs&apos;, &apos;s&apos;, &apos;m&apos;, &apos;l&apos;, &apos;xl&apos;](hide under xxs, xs, s, m, l, xl breakpoint&#xFF09;</td>\n<td>Boolean/String/Array</td>\n<td>-</td>\n</tr>\n</tbody>\n</table>\n<h3 id=\"grid-col\">Grid.Col<a href=\"#grid-col\" class=\"anchor\">#</a></h3><table>\n<thead>\n<tr>\n<th>Param</th>\n<th>Descripiton</th>\n<th>Type</th>\n<th>Default Value</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td>children</td>\n<td>content of the column</td>\n<td>ReactNode</td>\n<td>-</td>\n</tr>\n<tr>\n<td>span</td>\n<td>width of the column<br><br><strong>option</strong>:<br>1, 2, 3, ..., 22, 23, 24</td>\n<td>String/Number</td>\n<td>-</td>\n</tr>\n<tr>\n<td>fixedSpan</td>\n<td>width of the fixed column, the unit width is 20px<br><br><strong>option</strong>:<br>1, 2, 3, ..., 28, 29, 30</td>\n<td>String/Number</td>\n<td>-</td>\n</tr>\n<tr>\n<td>offset</td>\n<td>(IE9 is not supported) the offset of the column<br><br><strong>option</strong>:<br>1, 2, 3, ..., 22, 23, 24</td>\n<td>String/Number</td>\n<td>-</td>\n</tr>\n<tr>\n<td>fixedOffset</td>\n<td>(IE9 is not supported) the fixed offset of the column, the unit width is 20px<br><br><strong>option</strong>:<br>1, 2, 3, ..., 28, 29, 30</td>\n<td>String/Number</td>\n<td>-</td>\n</tr>\n<tr>\n<td>align</td>\n<td>(IE9 is not supported) vertical alignment of columns, it can override the Row&apos;s align property<br><br><strong>option</strong>:<br>&apos;top&apos;, &apos;center&apos;, &apos;bottom&apos;, &apos;baseline&apos;, &apos;stretch&apos;</td>\n<td>Enum</td>\n<td>-</td>\n</tr>\n<tr>\n<td>hidden</td>\n<td>whether display or hide the column under different breakpoints.<br><br><strong>option</strong>:<br>true(always hide)<br>false(always display)<br>&apos;xs&apos;(hide under xs breakpoint&#xFF09;<br>[&apos;xxs&apos;, &apos;xs&apos;, &apos;s&apos;, &apos;m&apos;, &apos;l&apos;, &apos;xl&apos;](hide under xxs, xs, s, m, l, xl breakpoint&#xFF09;</td>\n<td>Boolean/String/Array</td>\n<td>-</td>\n</tr>\n<tr>\n<td>xxs</td>\n<td>&gt;=320px, responsive grid, it can be a span string or an object with span and offset property</td>\n<td>String/Number/Object</td>\n<td>-</td>\n</tr>\n<tr>\n<td>xs</td>\n<td>&gt;=480px, responsive grid, it can be a span string or an object with span and offset property</td>\n<td>String/Number/Object</td>\n<td>-</td>\n</tr>\n<tr>\n<td>s</td>\n<td>&gt;=720px, responsive grid, it can be a span string or an object with span and offset property</td>\n<td>String/Number/Object</td>\n<td>-</td>\n</tr>\n<tr>\n<td>m</td>\n<td>&gt;=990px, responsive grid, it can be a span string or an object with span and offset property</td>\n<td>String/Number/Object</td>\n<td>-</td>\n</tr>\n<tr>\n<td>l</td>\n<td>&gt;=1200px, responsive grid, it can be a span string or an object with span and offset property</td>\n<td>String/Number/Object</td>\n<td>-</td>\n</tr>\n<tr>\n<td>xl</td>\n<td>&gt;=1500px, responsive grid, it can be a span string or an object with span and offset property</td>\n<td>String/Number/Object</td>\n<td>-</td>\n</tr>\n<tr>\n<td>component</td>\n<td>render node &apos;div&apos;</td>\n<td>String</td>\n<td>&apos;div&apos;</td>\n</tr>\n</tbody>\n</table>\n"}