{"meta":"<p>Display a notification message globally.</p>\n<h2 id=\"when-to-use\">When To Use<a href=\"#when-to-use\" class=\"anchor\">#</a></h2><p>To display a notification message at any of the four corners of the viewport. Typically it can be used in the following cases:</p>\n<ul>\n<li>A notification with complex content.</li>\n<li>A notification providing a feedback based on the user interaction. Or it may show some details about upcoming steps the user may have to follow.</li>\n<li>A notification that is pushed by the application.</li>\n</ul>\n<h2 id=\"guide\">Guide<a href=\"#guide\" class=\"anchor\">#</a></h2><h2 id=\"api\">API<a href=\"#api\" class=\"anchor\">#</a></h2>","api":"<ul>\n<li><code>Notification.success(config)</code></li>\n<li><code>Notification.error(config)</code></li>\n<li><code>Notification.warning(config)</code></li>\n<li><code>Notification.notice(config)</code></li>\n<li><code>Notification.help(config)</code></li>\n<li><code>Notification.open(config)</code></li>\n<li><code>Notification.close(key: String)</code></li>\n<li><code>Notification.destroy()</code></li>\n</ul>\n<p>The properties of config are as follows:</p>\n<table>\n<thead>\n<tr>\n<th>Property</th>\n<th>Description</th>\n<th>Type</th>\n<th>Default</th>\n<th>Version</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td>key</td>\n<td>The unique identifier of the Notification</td>\n<td>String</td>\n<td>-</td>\n<td></td>\n</tr>\n<tr>\n<td>title</td>\n<td>The title of notification box (required)</td>\n<td>String\\</td>\n<td>ReactNode</td>\n<td>-</td>\n<td></td>\n</tr>\n<tr>\n<td>content</td>\n<td>The content of notification box (required)</td>\n<td>String\\</td>\n<td>ReactNode</td>\n<td>-</td>\n<td></td>\n</tr>\n<tr>\n<td>duration</td>\n<td>Time in seconds before Notification is closed. When set to 0 or null, it will never be closed automatically</td>\n<td>Number</td>\n<td>4.5</td>\n<td></td>\n</tr>\n<tr>\n<td>icon</td>\n<td>Customized icon</td>\n<td>ReactNode</td>\n<td>-</td>\n<td></td>\n</tr>\n<tr>\n<td>style</td>\n<td>Customized inline style</td>\n<td><a href=\"https://github.com/DefinitelyTyped/DefinitelyTyped/blob/e434515761b36830c3e58a970abf5186f005adac/types/react/index.d.ts#L794\" target=\"_blank\">React.CSSProperties</a></td>\n<td>-</td>\n<td></td>\n</tr>\n<tr>\n<td>className</td>\n<td>Customized CSS class</td>\n<td>String</td>\n<td>-</td>\n<td></td>\n</tr>\n<tr>\n<td>onClose</td>\n<td>Specify a function that will be called when the close button is clicked</td>\n<td>Function</td>\n<td>-</td>\n<td></td>\n</tr>\n<tr>\n<td>onClick</td>\n<td>Specify a function that will be called when the notification is clicked</td>\n<td>Function</td>\n<td>-</td>\n</tr>\n</tbody>\n</table>\n<p><code>notification</code> also provides a global <code>config()</code> method that can be used for specifying the default options. Once this method is used, all the notification boxes will take into account these globally defined options when displaying.</p>\n<ul>\n<li><code>Notification.config(options)</code></li>\n</ul>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\">Notification<span class=\"token punctuation\">.</span><span class=\"token function\">config</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n  placement<span class=\"token punctuation\">:</span> <span class=\"token string\">&apos;bottomRight&apos;</span><span class=\"token punctuation\">,</span>\n  duration<span class=\"token punctuation\">:</span> <span class=\"token number\">3000</span><span class=\"token punctuation\">,</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><table>\n<thead>\n<tr>\n<th>Property</th>\n<th>Description</th>\n<th>Type</th>\n<th>Default</th>\n<th>Version</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td>duration</td>\n<td>Time in seconds before Notification is closed. When set to 0 or null, it will never be closed automatically</td>\n<td>Number</td>\n<td>4.5</td>\n<td></td>\n</tr>\n<tr>\n<td>maxCount</td>\n<td>Max visible count, default Infinity</td>\n<td>Number</td>\n<td>-</td>\n<td></td>\n</tr>\n<tr>\n<td>getContainer</td>\n<td>Return the mount node for Notification</td>\n<td>() =&gt; HTMLNode</td>\n<td>() =&gt; document.body</td>\n<td></td>\n</tr>\n<tr>\n<td>offset</td>\n<td>Offset after align, [x, y]</td>\n<td>Array</td>\n<td>[30, 30]</td>\n<td></td>\n</tr>\n<tr>\n<td>placement</td>\n<td>Position of Notification, can be one of <code>tl</code> <code>tr</code> <code>bl</code> <code>br</code></td>\n<td>String</td>\n<td>topRight</td>\n<td></td>\n</tr>\n<tr>\n<td>size</td>\n<td>Use <code>Message</code> size prop</td>\n<td>String</td>\n<td>large</td>\n</tr>\n</tbody>\n</table>\n"}