{"meta":"<h2 id=\"guide\">Guide<a href=\"#guide\" class=\"anchor\">#</a></h2><h3 id=\"when-to-use\">When to use<a href=\"#when-to-use\" class=\"anchor\">#</a></h3><h4 id=\"select\">Select<a href=\"#select\" class=\"anchor\">#</a></h4><p>If you don&apos;t expect the user-entered values &#x200B;&#x200B;to take effect but just select, use Select. You can also use Select&apos;s showSearch property to filter.</p>\n<h3 id=\"autocomplete\">AutoComplete<a href=\"#autocomplete\" class=\"anchor\">#</a></h3><p>AutoComplete retains the values &#x200B;&#x200B;entered by the user, essentially the Input component, which extends the capabilities of autocomplete, so the properties of the Input component can be passed directly.</p>\n<h3 id=\"common-problem\">common problem<a href=\"#common-problem\" class=\"anchor\">#</a></h3><h4 id=\"there-is-a-similar-warning-for-flatternchildren\">There is a similar warning for <code>flatternChildren</code><a href=\"#there-is-a-similar-warning-for-flatternchildren\" class=\"anchor\">#</a></h4><p>Select uses <code>value</code> as the key of the menu item by default. If the key value is not set, the default sequence index is used as the key value to ensure that these values &#x200B;&#x200B;do not duplicate.</p>\n<h4 id=\"use-of-datasource\">Use of dataSource<a href=\"#use-of-datasource\" class=\"anchor\">#</a></h4><p>Select supports both children and dataSource as the data source in the props. If set at the same time, children will prevail.</p>\n<p>Note: 1. Select uses <code>value</code> as the <code>key</code> value of the rendered menu item by default, so <code>value</code> cannot be repeated, otherwise the drop-down menu cannot be rendered. 2. Value does not allow null/undefined/object/array type values</p>\n<ol>\n<li>The way <code>children</code></li>\n</ol>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select</span></span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">\n    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select.Option</span></span> <span class=\"token attr-name\">value</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">&quot;</span>option1<span class=\"token punctuation\">&quot;</span></span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">option1</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select.Option</span></span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">\n    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select.Option</span></span> <span class=\"token attr-name\">value</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">&quot;</span>option2<span class=\"token punctuation\">&quot;</span></span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">option2</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select.Option</span></span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">\n    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select.Option</span></span> <span class=\"token attr-name\">disabled</span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">disabled</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select.Option</span></span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">\n</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select</span></span><span class=\"token punctuation\">&gt;</span></span><span class=\"token punctuation\">;</span></code></pre></div><ol start=\"2\">\n<li>The way <code>props</code></li>\n</ol>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">const</span> dataSource <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span>\n    <span class=\"token punctuation\">{</span>label<span class=\"token punctuation\">:</span><span class=\"token string\">&apos;option1&apos;</span><span class=\"token punctuation\">,</span> value<span class=\"token punctuation\">:</span><span class=\"token string\">&apos;option1&apos;</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">{</span>label<span class=\"token punctuation\">:</span><span class=\"token string\">&apos;option2&apos;</span><span class=\"token punctuation\">,</span> value<span class=\"token punctuation\">:</span><span class=\"token string\">&apos;option2&apos;</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">{</span>label<span class=\"token punctuation\">:</span><span class=\"token string\">&apos;disabled&apos;</span><span class=\"token punctuation\">,</span> disabled<span class=\"token punctuation\">:</span><span class=\"token boolean\">true</span><span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">]</span>\n<span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select</span></span> <span class=\"token attr-name\">dataSource</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>dataSource<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">/&gt;</span></span></code></pre></div><h4 id=\"customize-popup-layer\">Customize Popup Layer<a href=\"#customize-popup-layer\" class=\"anchor\">#</a></h4><p>See the <code>Embedded layer customization</code> in the example. The only thing to notice is that the elements of <code>overlay</code> remember to pass through props.\nThis is because the layer&apos;s animation of the overlay is implemented by <code>className</code>. If you don&apos;t pass props, you will not be able to listen to the end of the animation.</p>\n<h2 id=\"api\">API<a href=\"#api\" class=\"anchor\">#</a></h2>","api":"<h3 id=\"select\">Select<a href=\"#select\" class=\"anchor\">#</a></h3><table>\n<thead>\n<tr>\n<th>Param</th>\n<th>Descripiton</th>\n<th>Type</th>\n<th>Default Value</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td>Size</td>\n<td>selector size<br><br><strong>optional values</strong>:<br>&apos;small&apos;, &apos;medium&apos;, &apos;large&apos;</td>\n<td>Enum</td>\n<td>&apos;medium&apos;</td>\n</tr>\n<tr>\n<td>value</td>\n<td>Current value for controlled mode</td>\n<td>any</td>\n<td>-</td>\n</tr>\n<tr>\n<td>defaultValue</td>\n<td>initial default</td>\n<td>any</td>\n<td>-</td>\n</tr>\n<tr>\n<td>onChange</td>\n<td>Callback that fires when Select changes <br><br> <strong>Signature</strong>:<br>Function(value: mixed, actionType: String) =&gt; void<br><strong>Parameters</strong>:<br> <em>value</em>: {mixed} Selected value <br><em>actionType</em>: {String} Triggered, &apos;itemClick&apos;, &apos;enter&apos;, &apos;tag&apos; <br> <em>item</em>: {mixed} value in dataSource(only useDetailValue=false)</td>\n<td>Function</td>\n<td>func.noop</td>\n</tr>\n<tr>\n<td>placeholder</td>\n<td>placeholder when there is no value</td>\n<td>ReactNode</td>\n<td>-</td>\n</tr>\n<tr>\n<td>autoWidth</td>\n<td>Drop-down menu to align with selector</td>\n<td>Boolean</td>\n<td>true</td>\n</tr>\n<tr>\n<td>label</td>\n<td>custom inline label</td>\n<td>ReactNode</td>\n<td>-</td>\n</tr>\n<tr>\n<td>hasClear</td>\n<td>Clear button</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>state</td>\n<td>validate state<br><br><strong>Optional</strong>:<br>&apos;error&apos;, &apos;loading&apos;</td>\n<td>Enum</td>\n<td>-</td>\n</tr>\n<tr>\n<td>readOnly</td>\n<td>Is read-only, can be expanded in read-only mode but cannot be selected</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>disabled</td>\n<td>Disable selectors</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>visible</td>\n<td>The current shell is displayed</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>defaultVisible</td>\n<td>Does the layer initialization show</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>onVisibleChange</td>\n<td>Callback triggered when the layer is displayed or hidden <br><br> <strong>Signature</strong>:<br>Function(visible: Boolean) =&gt; void<br><strong>Parameters</strong>:<br><em>visible</em>: {Boolean} Does the shell display</td>\n<td>Function</td>\n<td>func.noop</td>\n</tr>\n<tr>\n<td>popupContainer</td>\n<td>shell container node</td>\n<td>String/Function</td>\n<td>-</td>\n</tr>\n<tr>\n<td>popupClassName</td>\n<td>className of the shell</td>\n<td>any</td>\n<td>-</td>\n</tr>\n<tr>\n<td>popupStyle</td>\n<td>Inline style of the shell</td>\n<td>Object</td>\n<td>-</td>\n</tr>\n<tr>\n<td>popupProps</td>\n<td>Attributes added to the shell</td>\n<td>Object</td>\n<td>{}</td>\n</tr>\n<tr>\n<td>followTrigger</td>\n<td>follow Trigger or not</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>popupContent</td>\n<td>Content of custom shell</td>\n<td>ReactNode</td>\n<td>-</td>\n</tr>\n<tr>\n<td>filterLocal</td>\n<td>Whether to use local filtering, turn this off when the data source is remote</td>\n<td>Boolean</td>\n<td>true</td>\n</tr>\n<tr>\n<td>filter</td>\n<td>A local filter method that returns a Boolean value to determine whether to keep <br><br><strong>Signature</strong>:<br>Function() =&gt; void</td>\n<td>Function</td>\n<td>filter</td>\n</tr>\n<tr>\n<td>dataSource</td>\n<td>The incoming data source that can dynamically render children, as described in [DataSource Usage] (Use of #dataSource)</td>\n<td>Array&lt;Object/Boolean/Number/String&gt;</td>\n<td>-</td>\n</tr>\n<tr>\n<td>itemRender</td>\n<td>How to render MenuItem content <br><br><br><br><br><br><br>Function(item: Object, searchValue: String) =&gt; ReactNode<br><strong>Parameters:<br><em>item</em>: {Object} Item for render node<br><em>searchValue</em>: {String} Search keyword (if search is enabled) <br></strong>Return value:<br>{ReactNode} item node<br></td>\n<td>Function</td>\n<td>-</td>\n</tr>\n<tr>\n<td>mode</td>\n<td>Selector mode <br><br><strong> Optional </strong>:<br>&apos;single&apos;, &apos;multiple&apos;, &apos;tag&apos;</td>\n<td>Enum</td>\n<td>&apos;single&apos;</td>\n</tr>\n<tr>\n<td>notFoundContent</td>\n<td>Empty copy of the shell content</td>\n<td>ReactNode</td>\n<td>&apos;No options&apos;</td>\n</tr>\n<tr>\n<td>hasBorder</td>\n<td>Whether there is a border</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>showSearch</td>\n<td>Can search after expansion (fixed to true in tag mode)</td>\n<td>Boolean</td>\n<td>false</td>\n</tr>\n<tr>\n<td>onSearch</td>\n<td>Callback when the search box value changes <br><br> <strong>Signature</strong>:<br>Function(value: String) =&gt; void<br><strong>Parameters</strong>:<br><em>value</em>: {String } Data</td>\n<td>Function</td>\n<td>func.noop</td>\n</tr>\n<tr>\n<td>onSearchClear</td>\n<td>Callback when the search box value is cleared <br><br> <strong>Signature</strong>:<br>Function(value: String) =&gt; void<br><strong>Parameters</strong>:<br><em>actionType</em>: {String} triggered method, &apos;itemClick&apos;, &apos;popupClose&apos;</td>\n<td>Function</td>\n<td>func.noop</td>\n</tr>\n<tr>\n<td>hasSelectAll</td>\n<td>Is there a Select All Function in Multiselect Mode</td>\n<td>Boolean/String</td>\n<td>-</td>\n</tr>\n<tr>\n<td>fillProps</td>\n<td>key to fill the value of the select box key??</td>\n<td>String</td>\n<td>-</td>\n</tr>\n<tr>\n<td>useDetailValue</td>\n<td>value returned by onChange object using dataSource</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>cacheValue</td>\n<td>dataSource keeps the selected content</td>\n<td>Boolean</td>\n<td>true</td>\n</tr>\n<tr>\n<td>valueRender</td>\n<td>Methods for rendering Select to display content <br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><strong> Parameters</strong>:<br><em>item</em>: {Object} Render node&apos;s item<br><strong>return value </strong>:<br>{ReactNode} show content <br></td>\n<td>Function</td>\n<td>item =&gt; item.label \\</td>\n<td>\\</td>\n<td>item.value</td>\n</tr>\n<tr>\n<td>searchValue</td>\n<td>Controlled search value, generally not set</td>\n<td>String</td>\n<td>-</td>\n</tr>\n<tr>\n<td>tagInline</td>\n<td>show in one line or not</td>\n<td>Boolean</td>\n<td>false</td>\n</tr>\n<tr>\n<td>maxTagCount</td>\n<td>max count of tag can be show</td>\n<td>Number</td>\n<td>-</td>\n</tr>\n<tr>\n<td>maxTagPlaceholder</td>\n<td>if selected tags&apos; length is over maxTagCount, what to show <br><br><strong>&#x7B7E;&#x540D;</strong>:<br>Function() =&gt; void</td>\n<td>Function</td>\n<td>(selected, total) =&gt; <code>${selected} / ${total}</code></td>\n</tr>\n<tr>\n<td>onRemove</td>\n<td>tag Delete callback <br><br><br><strong>Signature</strong>:<br>Function(item: object) =&gt; void<br><strong>Parameters</strong>:<br><em>item</em>: {object} Render node&apos;s Item</td>\n<td>Function</td>\n<td>func.noop</td>\n</tr>\n<tr>\n<td>onFocus</td>\n<td>focus event<br><br><strong>&#x7B7E;&#x540D;</strong>:<br>Function() =&gt; void</td>\n<td>Function</td>\n<td>func.noop</td>\n</tr>\n<tr>\n<td>onBlur</td>\n<td>blur event<br><br><strong>&#x7B7E;&#x540D;</strong>:<br>Function() =&gt; void</td>\n<td>Function</td>\n<td>func.noop</td>\n</tr>\n<tr>\n<td>onToggleHighlightItem</td>\n<td>callback func while highlight item changed <br><br><strong>&#x7B7E;&#x540D;</strong>:<br>Function() =&gt; void</td>\n<td>Function</td>\n<td>func.noop</td>\n</tr>\n<tr>\n<td>hiddenSelected</td>\n<td>hide menu after selected (only mode=&quot;multiple&quot; or &quot;tag&quot;)</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n</tbody>\n</table>\n<h3 id=\"select-autocomplete\">Select.AutoComplete<a href=\"#select-autocomplete\" class=\"anchor\">#</a></h3><table>\n<thead>\n<tr>\n<th>Param</th>\n<th>Descripiton</th>\n<th>Type</th>\n<th>Default Value</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td>size</td>\n<td>selector size<br><br><strong>optional values</strong>:<br>&apos;small&apos;, &apos;medium&apos;, &apos;large&apos;</td>\n<td>Enum</td>\n<td>&apos;medium&apos;</td>\n</tr>\n<tr>\n<td>value</td>\n<td>current value for controlled mode</td>\n<td>String/Number</td>\n<td>-</td>\n</tr>\n<tr>\n<td>defaultValue</td>\n<td>Initialization Default</td>\n<td>String/Number</td>\n<td>-</td>\n</tr>\n<tr>\n<td>onChange</td>\n<td>Callback that fires when Select changes <br><br> <strong>Signature</strong>:<br>Function(value: mixed, actionType: String) =&gt; void<br><strong>Parameters</strong>:<br> <em>value</em>: {mixed} selected value<br><em>actionType</em>: {String} triggered method, &apos;itemClick&apos;, &apos;enter&apos;, &apos;change&apos;</td>\n<td>Function</td>\n<td>-</td>\n</tr>\n<tr>\n<td>placeholder</td>\n<td>placeholder when there is no value</td>\n<td>ReactNode</td>\n<td>-</td>\n</tr>\n<tr>\n<td>autoWidth</td>\n<td>Drop-down menu to align with selector</td>\n<td>Boolean</td>\n<td>true</td>\n</tr>\n<tr>\n<td>label</td>\n<td>custom inline label</td>\n<td>ReactNode</td>\n<td>-</td>\n</tr>\n<tr>\n<td>hasClear</td>\n<td>Clear button</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>state</td>\n<td>validate state<br><br><strong>Optional</strong>:<br>&apos;error&apos;, &apos;loading&apos;</td>\n<td>Enum</td>\n<td>-</td>\n</tr>\n<tr>\n<td>readOnly</td>\n<td>Is read-only, can be expanded in read-only mode but cannot be selected</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>disabled</td>\n<td>Disable selectors</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>visible</td>\n<td>The current shell is displayed</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>defaultVisible</td>\n<td>Does the layer initialization show</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>popupContainer</td>\n<td>shell container node</td>\n<td>String/Function</td>\n<td>-</td>\n</tr>\n<tr>\n<td>popupClassName</td>\n<td>className of the shell</td>\n<td>any</td>\n<td>-</td>\n</tr>\n<tr>\n<td>popupStyle</td>\n<td>Inline style of the shell</td>\n<td>Object</td>\n<td>-</td>\n</tr>\n<tr>\n<td>popupProps</td>\n<td>Attributes added to the shell</td>\n<td>Object</td>\n<td>{}</td>\n</tr>\n<tr>\n<td>followTrigger</td>\n<td>follow Trigger or not</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>popupContent</td>\n<td>Content of custom shell</td>\n<td>ReactNode</td>\n<td>-</td>\n</tr>\n<tr>\n<td>filterLocal</td>\n<td>Whether to use local filtering, turn this off when the data source is remote</td>\n<td>Boolean</td>\n<td>true</td>\n</tr>\n<tr>\n<td>filter</td>\n<td>Local filter method, returning a Boolean value to determine whether to keep <br><br><strong>Signature</strong>:<br>Function() =&gt; void</td>\n<td>Function</td>\n<td>filter</td>\n</tr>\n<tr>\n<td>dataSource</td>\n<td>Incoming data source that can dynamically render children</td>\n<td>Array&lt;Object/String&gt;</td>\n<td>-</td>\n</tr>\n<tr>\n<td>itemRender</td>\n<td>How to render MenuItem content <br><br><strong>Signature</strong>:<br>Function(item: Object) =&gt; ReactNode<br><strong>Parameters</strong>:<br><em>item</em>: {Object} Rendering The node&apos;s item<br><strong>return value</strong>:<br>{ReactNode} item node<br></td>\n<td>Function</td>\n<td>-</td>\n</tr>\n<tr>\n<td>fillProps</td>\n<td>key?? of the value filled into the selection box, default value</td>\n<td>String</td>\n<td>&apos;value&apos;</td>\n</tr>\n<tr>\n<td>onToggleHighlightItem</td>\n<td>callback func while highlight item changed <br><br><strong>&#x7B7E;&#x540D;</strong>:<br>Function() =&gt; void</td>\n<td>Function</td>\n<td>func.noop</td>\n</tr>\n</tbody>\n</table>\n<h3 id=\"select-optiongroup\">Select.OptionGroup<a href=\"#select-optiongroup\" class=\"anchor\">#</a></h3><table>\n<thead>\n<tr>\n<th>Param</th>\n<th>Descripiton</th>\n<th>Type</th>\n<th>Default Value</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td>label</td>\n<td>Grouping text</td>\n<td>ReactNode</td>\n<td>-</td>\n</tr>\n</tbody>\n</table>\n<h3 id=\"select-option\">Select.Option<a href=\"#select-option\" class=\"anchor\">#</a></h3><table>\n<thead>\n<tr>\n<th>Param</th>\n<th>Descripiton</th>\n<th>Type</th>\n<th>Default Value</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td>value</td>\n<td>option value</td>\n<td>any</td>\n<td>-</td>\n</tr>\n<tr>\n<td>disabled</td>\n<td>disabled</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n</tbody>\n</table>\n<h2 id=\"aria-and-keyboard\">ARIA and KeyBoard<a href=\"#aria-and-keyboard\" class=\"anchor\">#</a></h2><table>\n<thead>\n<tr>\n<th style=\"text-align:left\">&#x6309;&#x952E;</th>\n<th style=\"text-align:left\">&#x8BF4;&#x660E;</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td style=\"text-align:left\">Up Arrow</td>\n<td style=\"text-align:left\">Get the previous item focus of the current item</td>\n</tr>\n<tr>\n<td style=\"text-align:left\">Down Arrow</td>\n<td style=\"text-align:left\">Get the next item focus of the current item</td>\n</tr>\n<tr>\n<td style=\"text-align:left\">Enter</td>\n<td style=\"text-align:left\">Open the list or select current item</td>\n</tr>\n<tr>\n<td style=\"text-align:left\">Esc</td>\n<td style=\"text-align:left\">Close the list</td>\n</tr>\n</tbody>\n</table>\n"}