{"title":"使用自定义组件","meta":{"title":"使用自定义组件","description":"\n<p>你可以为传递自定义组件到 Slider 组件中。前提是该组件一定要开放透传 props 到下层组件或元素，Slider 底层需要执行元素的 clone 操作。</p>\n","order":"16"},"codes":{"jsx":"import { Slider } from '@alifd/next';\nimport PropTypes from 'prop-types';\n\nconst pages = [1, 2, 3, 4];\n\nfunction Inner({ children, ...others }) {\n    // Note that to transparently pass other attributes to the lower node, the Slider needs to perform the element's clone operation.\n    return (\n        <div {...others}>\n            {children}\n        </div>\n    );\n}\n\nInner.propTypes = {\n    children: PropTypes.any\n};\n\nconst slider = (<Slider>\n    {\n        pages.map((page, index) => {\n            return <Inner className=\"custom-inner\" key={index}>custom {page}</Inner>;\n        })\n    }\n</Slider>);\n\nReactDOM.render(<div>\n    {slider}\n</div>\n    , mountNode);\n","css":".custom-inner {\n    background: #4F74B3;\n    color: #fff;\n    line-height: 150px;\n    text-align: center;\n    margin-top: 0;\n    margin-bottom: 0;\n}\n"},"body":"\n\n````jsx\nimport { Slider } from '@alifd/next';\nimport PropTypes from 'prop-types';\n\nconst pages = [1, 2, 3, 4];\n\nfunction Inner({ children, ...others }) {\n    // Note that to transparently pass other attributes to the lower node, the Slider needs to perform the element's clone operation.\n    return (\n        <div {...others}>\n            {children}\n        </div>\n    );\n}\n\nInner.propTypes = {\n    children: PropTypes.any\n};\n\nconst slider = (<Slider>\n    {\n        pages.map((page, index) => {\n            return <Inner className=\"custom-inner\" key={index}>custom {page}</Inner>;\n        })\n    }\n</Slider>);\n\nReactDOM.render(<div>\n    {slider}\n</div>\n    , mountNode);\n````\n\n````css\n.custom-inner {\n    background: #4F74B3;\n    color: #fff;\n    line-height: 150px;\n    text-align: center;\n    margin-top: 0;\n    margin-bottom: 0;\n}\n````","html":"<script>(function(){'use strict';\n\nvar _next = require('@alifd/next');\n\nvar _propTypes = require('prop-types');\n\nvar _propTypes2 = _interopRequireDefault(_propTypes);\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\nfunction _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }\n\nvar pages = [1, 2, 3, 4];\n\nfunction Inner(_ref) {\n    var children = _ref.children,\n        others = _objectWithoutProperties(_ref, ['children']);\n\n    // Note that to transparently pass other attributes to the lower node, the Slider needs to perform the element's clone operation.\n    return React.createElement(\n        'div',\n        others,\n        children\n    );\n}\n\nInner.propTypes = {\n    children: _propTypes2.default.any\n};\n\nvar slider = React.createElement(\n    _next.Slider,\n    null,\n    pages.map(function (page, index) {\n        return React.createElement(\n            Inner,\n            { className: 'custom-inner', key: index },\n            'custom ',\n            page\n        );\n    })\n);\n\nReactDOM.render(React.createElement(\n    'div',\n    null,\n    slider\n), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> Slider <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> PropTypes <span class=\"token keyword\">from</span> <span class=\"token string\">'prop-types'</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> pages <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span><span class=\"token number\">1</span><span class=\"token punctuation\">,</span> <span class=\"token number\">2</span><span class=\"token punctuation\">,</span> <span class=\"token number\">3</span><span class=\"token punctuation\">,</span> <span class=\"token number\">4</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">function</span> <span class=\"token function\">Inner</span><span class=\"token punctuation\">(</span><span class=\"token parameter\"><span class=\"token punctuation\">{</span> children<span class=\"token punctuation\">,</span> <span class=\"token operator\">...</span>others <span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token comment\">// Note that to transparently pass other attributes to the lower node, the Slider needs to perform the element's clone operation.</span>\n    <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span>\n        <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token spread\"><span class=\"token punctuation\">{</span><span class=\"token punctuation\">...</span><span class=\"token attr-value\">others</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token punctuation\">{</span>children<span class=\"token punctuation\">}</span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span>\n    <span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\nInner<span class=\"token punctuation\">.</span>propTypes <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n    children<span class=\"token punctuation\">:</span> PropTypes<span class=\"token punctuation\">.</span>any\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> slider <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Slider</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n    </span><span class=\"token punctuation\">{</span>\n        pages<span class=\"token punctuation\">.</span><span class=\"token function\">map</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">page<span class=\"token punctuation\">,</span> index</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n            <span class=\"token keyword\">return</span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Inner</span></span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>custom-inner<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">key</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>index<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">custom </span><span class=\"token punctuation\">{</span>page<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Inner</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">;</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span>\n    <span class=\"token punctuation\">}</span><span class=\"token plain-text\">\n</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Slider</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n    </span><span class=\"token punctuation\">{</span>slider<span class=\"token punctuation\">}</span><span class=\"token plain-text\">\n</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span>\n    <span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><style type=\"text/css\">.custom-inner {\n    background: #4F74B3;\n    color: #fff;\n    line-height: 150px;\n    text-align: center;\n    margin-top: 0;\n    margin-bottom: 0;\n}</style><div class=\"highlight\"><pre class=\"language-css\"><code class=\"language-css\"><span class=\"token selector\">.custom-inner</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">background</span><span class=\"token punctuation\">:</span> #4F74B3<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">color</span><span class=\"token punctuation\">:</span> #fff<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">line-height</span><span class=\"token punctuation\">:</span> 150px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">text-align</span><span class=\"token punctuation\">:</span> center<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">margin-top</span><span class=\"token punctuation\">:</span> 0<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">margin-bottom</span><span class=\"token punctuation\">:</span> 0<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span></code></pre></div>"}